<?php

namespace Bydedi\Shipping\Chronopost;

use ChronopostStructCustomerValue;
use ChronopostStructRecipientValue;
use ChronopostStructRefValue;
use ChronopostStructShipperValue;

/**
 * Class Sticker
 * @package Bydedi\Shipping\Chronopost
 */
class Sticker
{
    /**
     * @var ChronopostStructShipperValue
     */
    protected $shipper;

    /**
     * @var ChronopostStructCustomerValue
     */
    protected $customer;

    /**
     * @var ChronopostStructRecipientValue
     */
    protected $recipient;

    /**
     * @var ChronopostStructRefValue
     */
    protected $ref;

    /**
     * @var string
     */
    protected $url_pdf;

    /**
     * @var string
     */
    protected $tracking;

    /**
     * @var string
     */
    protected $currency;

    /**
     * @var float
     */
    protected $port_value;

    /**
     * @var float
     */
    protected $weight;

    /**
     * @var string
     */
    protected $product_code;

    public static function createFromOrder($order)
    {

        $sticker = new static();

        if (!empty($order['livraison_societe'])) {
            $order['contact_name'] = $order['livraison_societe'];
            $order['livraison_prenom'] = $order['livraison_prenom'] . ' ' . $order['livraison_nom'];
            $order['livraison_nom'] = $order['livraison_societe'];
        } else {
            $order['contact_name'] = $order['client_prenom'] . ' ' . $order['client_nom'];
        }

        $sticker->setRecipient($order);

        if ($order['commande_livraison_code'] == 'CHRONO' && $order['livraison_pays_code'] == "FR") {
            $productCode = "01";
        } elseif ($order['commande_livraison_code'] == 'CHRONO' && $order['livraison_pays_code'] != "FR") {
            /**
             * Europe : chrono classic 44 (camion)
             * Internationnal : chrono express 17 (avion)
             */
            // $productCode = "17";
            $productCode = "44";
        } elseif ($order['commande_livraison_code'] == 'CHRONORELAIS') {
            $productCode = "86";
        } else {
            $productCode = "01";
        }

        $sticker->setProductCode($productCode);
        $sticker->setPortValue($order['commande_port_ht']);

        $sticker->setWeight($order['commande_poids']);

        if ($order['commande_livraison_code'] == 'CHRONORELAIS') {
            $recipientRef = $order['relais_id'];
        } else {
            $recipientRef = $order['client_prenom'] . ' ' . $order['client_nom'];
        }
        $sticker->setRef($recipientRef);

        $sticker->setCurrency('EUR');

        return $sticker;
    }

    public function setWeight($weight)
    {
        $this->weight = $weight;
        return $this;
    }

    /**
     * @param $url_pdf
     * @return $this
     */
    public function setUrlPDF($url_pdf)
    {
        $this->url_pdf = $url_pdf;
        return $this;
    }

    public function setTracking($tracking)
    {
        $this->tracking = $tracking;
        return $this;
    }

    public function setProductCode($product_code)
    {
        $this->product_code = $product_code;
        return $this;
    }

    public function setPortValue($port_value)
    {
        $this->port_value = $port_value;
        return $this;
    }

    public function setCurrency($currency)
    {
        $this->currency = $currency;
        return $this;
    }

    public function setShipper(ChronopostStructShipperValue $shipper)
    {
        $this->shipper = $shipper;
        return $this;
    }

    /**
     * @param $customer
     * @return $this
     */
    public function setCustomer(ChronopostStructCustomerValue $customer)
    {
        $this->customer = $customer;
        return $this;
    }

    /**
     * @param $recipient
     * @return $this
     */
    public function setRecipient($recipient)
    {
        $this->recipient = new ChronopostStructRecipientValue(
            $recipient['livraison_rue'],
            $recipient['livraison_rue2'],
            $recipient['livraison_ville'],
            $recipient['contact_name'],
            $recipient['livraison_pays_code'],
            $recipient['livraison_pays'],
            $recipient['client_email'],
            $recipient['client_telephone'],
            $recipient['livraison_nom'],
            $recipient['livraison_prenom'],
            $recipient['livraison_telephone'],
            0,
            $recipient['livraison_cp']
        );

        return $this;
    }

    /**
     * @param $recipientRef
     * @return $this
     */
    public function setRef($recipientRef)
    {
        $this->ref = new ChronopostStructRefValue("", "", $recipientRef, "");
        return $this;
    }

    /**
     * @return ChronopostStructShipperValue
     */
    public function getShipper()
    {
        return $this->shipper;
    }

    /**
     * @return ChronopostStructRecipientValue
     */
    public function getRecipient()
    {
        return $this->recipient;
    }

    /**
     * @return ChronopostStructCustomerValue
     */
    public function getCustomer()
    {
        return $this->customer;
    }

    /**
     * @return ChronopostStructRefValue
     */
    public function getRef()
    {
        return $this->ref;
    }

    /**
     * @return string
     */
    public function getUrlPdf()
    {
        return $this->url_pdf;
    }

    /**
     * @return string
     */
    public function getTracking()
    {
        return $this->tracking;
    }

    /**
     * @return string
     */
    public function getCurrency()
    {
        return $this->currency;
    }

    /**
     * @return float
     */
    public function getPortValue()
    {
        return $this->port_value;
    }

    /**
     * @return float
     */
    public function getWeight()
    {
        return $this->weight;
    }

    /**
     * @return string
     */
    public function getProductCode()
    {
        return $this->product_code;
    }
}
